.. _Tutorial5Demo:

==========
Tutorial 5
==========

Connecting to SQL:

.. report:: Tutorial5.ExpressionLevelWithSlices
   :render: line-plot
   :transform: histogram
   :tf-range: 0,100,4

   Expression level in house-keeping and regulatory genes
   in two experiments.

